<?php

/*
 * This file is used for controlling the data for the dashboard page
 */

// Setup cron jobs

if ( ! wp_next_scheduled('initialize_popup_stats_daily_cron')) {
	wp_schedule_event( time(), 'daily', 'initialize_popup_stats_daily_cron');
}

if ( ! wp_next_scheduled('setup_popup_email_stats_cron')) {
	wp_schedule_event( time(), 'daily', 'setup_popup_email_stats_cron');
}

if (!wp_next_scheduled('purge_popup_transients_cron')) {
	wp_schedule_event( time(), 'daily', 'purge_popup_transients_cron');
}

include_once(WPSITE_POPUP_PLUGIN_DIR . 'admin/model/db.php');
include_once(WPSITE_POPUP_PLUGIN_DIR . 'admin/model/list-table.php');

// Init model and controller classes

$wpsite_popup_list_table = new WPsite_Popup_List_Table();
$wpsite_popup_db = new WPsite_Popup_DB();

$license_key = self::get_license_key();

// Get the counts

$all_count = count( $wpsite_popup_db->get_popups() );
$active_count = count( $wpsite_popup_db->get_active() );
$inactive_count = count( $wpsite_popup_db->get_inactive() );

// Activate / Deactivate

if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "active") {

	// Check nonce

	if (isset($_REQUEST['wp_nonce']) && wp_verify_nonce($_REQUEST['wp_nonce'], self::$prefix . 'activate'))
		$wpsite_popup_db->set_active($_GET["popup_id"], $_GET["set_action"]);
}

// Delete

if(isset($_REQUEST['action']) && $_REQUEST["action"] == "delete") {

	// Check nonce

	if (isset($_REQUEST['wp_nonce']) && wp_verify_nonce($_REQUEST['wp_nonce'], self::$prefix . 'delete')) {

		// Check if popup is currently in an A/B Test

		$wpsite_popup_db = new WPsite_Popup_DB();
		$popup = $wpsite_popup_db->get_data_from_id($_GET['popup_id']);
		$popup['args'] = unserialize($popup['args']);
		$ab_popup = $wpsite_popup_db->get_data_from_id($popup['args']['ab_testing']['popup_id']);

		if (isset($ab_popup)) {

			$ab_popup['social']         = unserialize($ab_popup['social']);
			$ab_popup['news_letter']    = unserialize($ab_popup['news_letter']);
			$ab_popup['template']       = unserialize($ab_popup['template']);
			$ab_popup['trigger']        = unserialize($ab_popup['trigger']);
			$ab_popup['style']          = unserialize($ab_popup['style']);
			$ab_popup['args']           = unserialize($ab_popup['args']);

			$ab_popup['args']['ab_testing']['active'] = false;
			$ab_popup['args']['ab_testing']['popup_id'] = '0';
			$ab_popup['args']['ab_testing']['start_date'] = '0';
			$wpsite_popup_db->update_data($ab_popup);

		}

		// Delete record

		if(isset($_GET["popup_id"])) {
			$wpsite_popup_db->delete_data(esc_attr($_GET["popup_id"]));
		}

		?>
		<script type="text/javascript">
			window.location= "<?php echo get_admin_url() ;?>admin.php?page=<?php echo self::$dashboard_page; ?>";
		</script>
		<?php
	}
}

// Preview

if (isset($_REQUEST["action"]) && $_REQUEST["action"] == "preview") {

	// Check nonce

	if (isset($_REQUEST['wp_nonce']) && wp_verify_nonce($_REQUEST['wp_nonce'], self::$prefix . 'preview')) {

		global $wpdb;

		$data = $wpdb->get_results($wpdb->prepare("SELECT * FROM `" . WPsite_Popup_DB::getTableName() . "` WHERE id = %d", $_REQUEST['popup_id']), 'ARRAY_A');

		$data[0]['timer'] = '0';

		WPsite_Popup_Functions::generate_code($data[0], unserialize($data[0]['social']), unserialize($data[0]['news_letter']));
	}
}

// Dismiss notice

if (isset($_GET['action']) && $_GET['action'] != '' && isset($_GET['notice']) && $_GET['notice'] != '') {
	delete_transient(self::$prefix . 'admin_notice_' . $_GET['notice']);

	?>
	<script type="text/javascript">
		window.location = "<?php echo get_admin_url(); ?>admin.php?page=<?php echo self::$dashboard_page; ?>";
	</script>
	<?php
}

include_once(WPSITE_POPUP_PLUGIN_DIR . 'admin/views/dashboard.php');

wp_localize_script(self::$prefix . 'admin_js', 'wps_pf_data', array(
	'prefix_dash' 		=> self::$prefix_dash,
	'activate_text' 	=> __('Activate', self::$text_domain),
	'deactivate_text' 	=> __('Deactivate', self::$text_domain),
));