<?php

/*
 * This file is used for controlling the data for the stats page
 */

include_once(WPSITE_POPUP_PLUGIN_DIR . 'admin/model/db.php');

// Create Table if one does not exist

global $wpdb;

WPsite_Stats_PF::createTable();

if (isset($_GET['action']) && $_GET['action'] == 'ab-testing') {

	$wpsite_popup_db = new WPsite_Popup_DB();
	$popup = $wpsite_popup_db->get_data_from_id($_GET['popup_id']);
	$popup['args'] = unserialize($popup['args']);

}

// Get global settings

$global_settings = get_option(self::$prefix . 'global_settings');

if ( $global_settings === false ) {
	$global_settings = WPsite_Popups_Admin_Functions::default_global_settings();
}


// Save A/B Testing settings

if (isset($_GET['action']) && $_GET['action'] == 'ab-testing' && isset($_GET['action1']) && check_admin_referer(self::$prefix . 'ab_testing')) {

	$popup = $wpsite_popup_db->get_data_from_id($_GET['popup_id']);

	$popup['social']         = unserialize($popup['social']);
	$popup['news_letter']    = unserialize($popup['news_letter']);
	$popup['template']       = unserialize($popup['template']);
	$popup['trigger']        = unserialize($popup['trigger']);
	$popup['style']          = unserialize($popup['style']);
	$popup['args']           = unserialize($popup['args']);

	if ($_GET['action1'] == 'start') {

		$popup['args']['ab_testing']['active'] = true;
		$popup['args']['ab_testing']['start_date'] = date(WPSITE_POPUP_DATE_FORMAT);

		// Create new popup with same settings as current one.

		$ab_popup = $popup;
		$ab_popup['name'] .= ' A/B Testing';
		$ab_popup['args']['ab_testing']['active'] = true;
		$ab_popup['args']['ab_testing']['popup_id'] = $popup['id'];
		$ab_popup['args']['ab_testing']['start_date'] = date(WPSITE_POPUP_DATE_FORMAT);
		$wpsite_popup_db->add_data($ab_popup);

		$popup['args']['ab_testing']['popup_id'] = $wpdb->insert_id;

	} else if ($_GET['action1'] == 'stop') {
		$popup['args']['ab_testing']['active'] = false;
		$ab_popup = $wpsite_popup_db->get_data_from_id($popup['args']['ab_testing']['popup_id']);
		$popup['args']['ab_testing']['popup_id'] = '0';
		$popup['args']['ab_testing']['start_date'] = '';

		if (isset($ab_popup)) {

			$ab_popup['social']         = unserialize($ab_popup['social']);
			$ab_popup['news_letter']    = unserialize($ab_popup['news_letter']);
			$ab_popup['template']       = unserialize($ab_popup['template']);
			$ab_popup['trigger']        = unserialize($ab_popup['trigger']);
			$ab_popup['style']          = unserialize($ab_popup['style']);
			$ab_popup['args']           = unserialize($ab_popup['args']);

			$ab_popup['args']['ab_testing']['active'] = false;
			$ab_popup['args']['ab_testing']['popup_id'] = '0';
			$ab_popup['args']['ab_testing']['start_date'] = '';
			$wpsite_popup_db->update_data($ab_popup);
		}

	}

	$wpsite_popup_db->update_data($popup);
	?>
	<script type="text/javascript">
		window.location = "<?php echo get_admin_url(); ?>admin.php?page=<?php echo self::$dashboard_page; ?>";
	</script>
	<?php
}

// Export data

if (isset($_GET['export_data']) && $_GET['export_data'] == 'true' && check_admin_referer(self::$prefix . 'export_data')) {

	$start_date = date(WPSITE_POPUP_DATE_FORMAT, mktime(0, 0, 0, date("m")-1, date("d"), date("Y")));
	$end_date = date(WPSITE_POPUP_DATE_FORMAT, strtotime(current_time('mysql')));

	if (isset($_GET[self::$prefix_dash . 'start-date']) && $_GET[self::$prefix_dash . 'start-date'] != '') {
		$start_date = date(WPSITE_POPUP_DATE_FORMAT, strtotime($_GET[self::$prefix_dash . 'start-date']));
	}

	if (isset($_GET[self::$prefix_dash . 'end-date']) && $_GET[self::$prefix_dash . 'end-date'] != '') {
		$end_date = date(WPSITE_POPUP_DATE_FORMAT, strtotime($_GET[self::$prefix_dash . 'end-date']));
	}

	global $wpdb;
	$popup_stats = WPsite_Stats_PF::getStats($start_date, $end_date, $_GET['popup_id']);
	$popups = $wpdb->get_results("SELECT * FROM `" . WPsite_Popup_DB::getTableName() . "`");

	foreach ($popups as $popup) {
		foreach ($popup_stats as $key => $popup_stat) {
			if ($popup->id == $popup_stat['popup_id']) {
				$popup_stats[$key] = array('popup_name' => $popup->name) + $popup_stats[$key];

				$ctr = $popup_stats[$key]['impressions'] != 0 ? round(($popup_stats[$key]['clicks']/$popup_stats[$key]['impressions']) * 100,2) : 0;

				$popup_stats[$key]['click-through-rate'] = $ctr . '%';

			}
		}
	}

	// Unset indexes

	foreach ($popup_stats as $key => $popup_stat) {
		unset($popup_stats[$key]['id']);
		unset($popup_stats[$key]['popup_id']);
	}

	$filename =  self::$prefix . 'stats.csv';
	$export_file = fopen(WPSITE_POPUP_PLUGIN_DIR . 'exports/' . $filename, "w");
	fputcsv($export_file, array('Popup Name', 'Date', 'Impressions', 'Conversions', 'Conversion Rate'));

	foreach (array_reverse($popup_stats) as $popup_stat) {
	    fputcsv($export_file, $popup_stat);
	}

	fclose($export_file);

	?>
	<script type="text/javascript">
		window.location = '<?php echo WPSITE_POPUP_PLUGIN_URL . '/exports/download.php?filename=' . $filename; ?>';
	</script>
	<?php
}

$ab_start_date = date('m/d/Y');

if (isset($_GET['action']) && $_GET['action'] == 'ab-testing') {

	$wpsite_popup_db = new WPsite_Popup_DB();

	$popup = $wpsite_popup_db->get_data_from_id($_GET['popup_id']);
	$popup['args'] = unserialize($popup['args']);

	$ab_start_date = date('m/d/Y', strtotime($popup['args']['ab_testing']['start_date']));
}

wp_enqueue_script(self::$prefix . 'stats_js', WPSITE_POPUP_PLUGIN_URL . '/admin/js/stats.js', array('jquery'));
wp_localize_script(self::$prefix . 'stats_js', 'wps_pf_stats_data', array(
	'prefix_dash' 		=> self::$prefix_dash,
	'today'				=> date('m/d/Y'),
	'ab_start_date'		=> $ab_start_date,
));

include_once(WPSITE_POPUP_PLUGIN_DIR . 'admin/views/stats.php');